.. _`Main`: index.html
.. _`overview`: index.html
.. _`tutorial`: tutorial.html
.. _`fetch manual`: fetch.html
.. _`table definitions`: table_def.html
.. _`telemetry archive tables`: table_def.html
.. _`observation database`: observation_def.html
.. _`observation table definition`: observation_def.html
.. _`matplotlib`: http://matplotlib.sourceforge.net/
.. _`numpy`: http://numpy.scipy.org/
.. _`ipython`: http://ipython.scipy.org/moin/
.. _HEAsoft: http://heasarc.gsfc.nasa.gov/lheasoft/
.. _CIAO: http://cxc.harvard.edu/ciao/
.. _SAS: http://xmm.vilspa.esa.es/sas/

